@@ -60,17 +60,13 @@ class IntColumn(NumericStatsMixin, BaseColumnPrimitiveTypeProfiler):
         
         :return:
         """
-        histogram_method = self.histogram_bin_method_names[0]
-        if self.histogram_selection is not None:
-            histogram_method = self.histogram_selection
-            
         profile = dict(
-            min=self.min,
-            max=self.max,
-            mean=self.mean,
-            variance=self.variance,
-            stddev=self.stddev,
-            histogram=self.histogram_methods[histogram_method]['histogram'],
+            min=self.np_type_to_type(self.min),
+            max=self.np_type_to_type(self.max),
+            mean=self.np_type_to_type(self.mean),
+            variance=self.np_type_to_type(self.variance),
+            stddev=self.np_type_to_type(self.stddev),
+            histogram=self._get_best_histogram_for_profile(),
             quantiles=self.quantiles,
             times=self.times
         )
