@@ -111,7 +111,12 @@ class TestProfilerOptions(unittest.TestCase):
             self.assertTrue("data_label" not in profile_column.keys())
             self.assertIsNone(profile_column["categorical"])
             self.assertIsNone(profile_column["order"])
-            self.assertDictEqual({}, profile_column["statistics"])
+            self.assertDictEqual({
+                'sample_size': 2,
+                'null_count': 0,
+                'null_types': [],
+                'null_types_index': {}
+            }, profile_column["statistics"])
 
     @mock.patch('dataprofiler.profilers.text_column_profile.TextColumn'
                 '._update_vocab')
@@ -366,6 +371,7 @@ class TestDataLabelerCallWithOptions(unittest.TestCase):
         data_labeler = mock.Mock(spec=BaseDataLabeler)
         data_labeler.reverse_label_mapping = dict()
         data_labeler.model.num_labels = 0
+        data_labeler.model.requires_zero_mapping = False
         options.set({'data_labeler.data_labeler_object': data_labeler})
         with self.assertWarnsRegex(UserWarning,
                                    "The data labeler passed in will be used,"
