@@ -22,6 +22,7 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
         mock_DataLabeler.label_mapping = {"a": 0, "b": 1}
         mock_DataLabeler.reverse_label_mapping = {0: "a", 1: "b"}
         mock_DataLabeler.model.num_labels = 2
+        mock_DataLabeler.model.requires_zero_mapping = False
 
         def mock_predict(data, *args, **kwargs):
             len_data = len(data)
@@ -73,6 +74,24 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
         self.assertDictEqual(dict(a=2, b=1), profiler.rank_distribution)
         self.assertDictEqual(dict(a=2/3, b=1/3), profiler.label_representation)
 
+    def test_update_reserve_label_mapping(self, mock_instance):
+        self._setup_data_labeler_mock(mock_instance)
+        mock_DataLabeler = mock_instance.return_value
+        mock_DataLabeler.model.requires_zero_mapping = True
+        mock_DataLabeler.label_mapping = {"PAD": 0, "a": 1, "b": 2}
+        mock_DataLabeler.reverse_label_mapping = {0: "PAD", 1:"a", 2: "b"}
+        mock_DataLabeler.model.num_labels = 3
+
+        data = pd.Series(['1', '2', '3'])
+        profiler = DataLabelerColumn(data.name)
+        profiler.update(data)
+
+        self.assertEqual(["a", "b"], profiler._possible_data_labels)
+        self.assertEqual("a", profiler.data_label)
+        self.assertDictEqual(dict(a=2/3, b=1/3), profiler.avg_predictions)
+        self.assertDictEqual(dict(a=2, b=1), profiler.rank_distribution)
+        self.assertDictEqual(dict(a=2/3, b=1/3), profiler.label_representation)
+
     def test_data_label_low_accuracy(self, mock_instance):
         self._setup_data_labeler_mock(mock_instance)
 
@@ -91,6 +110,7 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
         mock_DataLabeler.reverse_label_mapping = \
             {0: "a", 1: "b", 2: "c", 3: "d"}
         mock_DataLabeler.model.num_labels = 4
+        mock_DataLabeler.model.requires_zero_mapping = False
 
         def mock_low_predict(data, *args, **kwargs):
             return {'pred': None, 'conf': np.array([
@@ -139,7 +159,6 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
             expected = defaultdict(float, {'data_labeler_predict': 2.0})
             self.assertEqual(expected, profiler.profile['times'])
 
-
     def test_label_match(self, mock_instance):
         """
         Test label match between avg_prediction and data_label_representation
@@ -150,6 +169,7 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
         mock_DataLabeler.reverse_label_mapping = \
             {0: "a", 1: "c", 2: "e", 3: "f"}
         mock_DataLabeler.model.num_labels = 4
+        mock_DataLabeler.model.requires_zero_mapping = False
 
         data = pd.Series(['1', '2', '3', '4', '5', '6'])
         profiler = DataLabelerColumn(data.name)
@@ -159,7 +179,6 @@ class TestDataLabelerColumnProfiler(unittest.TestCase):
         self.assertDictEqual(dict(a=0, c=0, e=0, f=0), profiler.label_representation)
         self.assertDictEqual(dict(a=0, c=0, e=0, f=0), profiler.avg_predictions)
 
-
     def test_profile_merge(self, mock_instance):
         self._setup_data_labeler_mock(mock_instance)
 
